@@ -5,6 +5,7 @@ from collections import Sequence
 from pathlib import Path
 
 import mmcv
+import numpy as np
 from mmcv import Config, DictAction
 
 from mmdet.core.utils import mask2ndarray
@@ -73,6 +74,10 @@ def main():
     args = parse_args()
     cfg = retrieve_data_cfg(args.config, args.skip_type, args.cfg_options)
 
+    if 'gt_semantic_seg' in cfg.train_pipeline[-1]['keys']:
+        cfg.data.train.pipeline = [
+            p for p in cfg.data.train.pipeline if p['type'] != 'SegRescale'
+        ]
     dataset = build_dataset(cfg.data.train)
 
     progress_bar = mmcv.ProgressBar(len(dataset))
@@ -82,21 +87,40 @@ def main():
                                 Path(item['filename']).name
                                 ) if args.output_dir is not None else None
 
+        gt_bboxes = item['gt_bboxes']
+        gt_labels = item['gt_labels']
         gt_masks = item.get('gt_masks', None)
         if gt_masks is not None:
             gt_masks = mask2ndarray(gt_masks)
 
+        gt_seg = item.get('gt_semantic_seg', None)
+        if gt_seg is not None:
+            pad_value = 255  # the padding value of gt_seg
+            sem_labels = np.unique(gt_seg)
+            all_labels = np.concatenate((gt_labels, sem_labels), axis=0)
+            all_labels, counts = np.unique(all_labels, return_counts=True)
+            stuff_labels = all_labels[np.logical_and(counts < 2,
+                                                     all_labels != pad_value)]
+            stuff_masks = gt_seg[None] == stuff_labels[:, None, None]
+            gt_labels = np.concatenate((gt_labels, stuff_labels), axis=0)
+            gt_masks = np.concatenate((gt_masks, stuff_masks.astype(np.uint8)),
+                                      axis=0)
+            # If you need to show the bounding boxes,
+            # please comment the following line
+            gt_bboxes = None
+
         imshow_det_bboxes(
             item['img'],
-            item['gt_bboxes'],
-            item['gt_labels'],
+            gt_bboxes,
+            gt_labels,
             gt_masks,
             class_names=dataset.CLASSES,
             show=not args.not_show,
             wait_time=args.show_interval,
             out_file=filename,
-            bbox_color=(255, 102, 61),
-            text_color=(255, 102, 61))
+            bbox_color=dataset.PALETTE,
+            text_color=(200, 200, 200),
+            mask_color=dataset.PALETTE)
 
         progress_bar.update()
 
