@@ -591,7 +591,7 @@ class CornerHead(BaseDenseHead, BBoxTestMixin):
             targets (dict): Corner target generated by `get_targets`.
 
         Returns:
-            tuple[torch.Tensor]: Losses of the head's differnet branches
+            tuple[torch.Tensor]: Losses of the head's different branches
             containing the following losses:
 
                 - det_loss (Tensor): Corner keypoint loss.
@@ -696,15 +696,6 @@ class CornerHead(BaseDenseHead, BBoxTestMixin):
                     rescale=rescale,
                     with_nms=with_nms))
 
-        if torch.onnx.is_in_onnx_export():
-            assert len(
-                img_metas
-            ) == 1, 'Only support one input image while in exporting to ONNX'
-
-            detections, labels = result_list[0]
-            # batch_size 1 here, [1, num_det, 5], [1, num_det]
-            return detections.unsqueeze(0), labels.unsqueeze(0)
-
         return result_list
 
     def _get_bboxes_single(self,
@@ -766,15 +757,8 @@ class CornerHead(BaseDenseHead, BBoxTestMixin):
             batch_bboxes /= batch_bboxes.new_tensor(img_meta['scale_factor'])
 
         bboxes = batch_bboxes.view([-1, 4])
-        scores = batch_scores.view([-1, 1])
-        clses = batch_clses.view([-1, 1])
-
-        # use `sort` instead of `argsort` here, since currently exporting
-        # `argsort` to ONNX opset version 11 is not supported
-        scores, idx = scores.sort(dim=0, descending=True)
-        bboxes = bboxes[idx].view([-1, 4])
-        scores = scores.view(-1)
-        clses = clses[idx].view(-1)
+        scores = batch_scores.view(-1)
+        clses = batch_clses.view(-1)
 
         detections = torch.cat([bboxes, scores.unsqueeze(-1)], -1)
         keepinds = (detections[:, -1] > -0.1)
@@ -788,33 +772,22 @@ class CornerHead(BaseDenseHead, BBoxTestMixin):
         return detections, labels
 
     def _bboxes_nms(self, bboxes, labels, cfg):
-        if labels.numel() == 0:
-            return bboxes, labels
-
         if 'nms_cfg' in cfg:
             warning.warn('nms_cfg in test_cfg will be deprecated. '
                          'Please rename it as nms')
         if 'nms' not in cfg:
             cfg.nms = cfg.nms_cfg
 
-        out_bboxes, keep = batched_nms(bboxes[:, :4], bboxes[:, -1], labels,
-                                       cfg.nms)
-        out_labels = labels[keep]
+        if labels.numel() > 0:
+            max_num = cfg.max_per_img
+            bboxes, keep = batched_nms(bboxes[:, :4], bboxes[:,
+                                                             -1].contiguous(),
+                                       labels, cfg.nms)
+            if max_num > 0:
+                bboxes = bboxes[:max_num]
+                labels = labels[keep][:max_num]
 
-        if len(out_bboxes) > 0:
-            # use `sort` to replace with `argsort` here
-            _, idx = torch.sort(out_bboxes[:, -1], descending=True)
-            max_per_img = out_bboxes.new_tensor(cfg.max_per_img).to(torch.long)
-            nms_after = max_per_img
-            if torch.onnx.is_in_onnx_export():
-                # Always keep topk op for dynamic input in onnx
-                from mmdet.core.export import get_k_for_topk
-                nms_after = get_k_for_topk(max_per_img, out_bboxes.shape[0])
-            idx = idx[:nms_after]
-            out_bboxes = out_bboxes[idx]
-            out_labels = out_labels[idx]
-
-        return out_bboxes, out_labels
+        return bboxes, labels
 
     def decode_heatmap(self,
                        tl_heat,
@@ -1051,3 +1024,60 @@ class CornerHead(BaseDenseHead, BBoxTestMixin):
         clses = gather_feat(clses, inds).float()
 
         return bboxes, scores, clses
+
+    def onnx_export(self,
+                    tl_heats,
+                    br_heats,
+                    tl_embs,
+                    br_embs,
+                    tl_offs,
+                    br_offs,
+                    img_metas,
+                    rescale=False,
+                    with_nms=True):
+        """Transform network output for a batch into bbox predictions.
+
+        Args:
+            tl_heats (list[Tensor]): Top-left corner heatmaps for each level
+                with shape (N, num_classes, H, W).
+            br_heats (list[Tensor]): Bottom-right corner heatmaps for each
+                level with shape (N, num_classes, H, W).
+            tl_embs (list[Tensor]): Top-left corner embeddings for each level
+                with shape (N, corner_emb_channels, H, W).
+            br_embs (list[Tensor]): Bottom-right corner embeddings for each
+                level with shape (N, corner_emb_channels, H, W).
+            tl_offs (list[Tensor]): Top-left corner offsets for each level
+                with shape (N, corner_offset_channels, H, W).
+            br_offs (list[Tensor]): Bottom-right corner offsets for each level
+                with shape (N, corner_offset_channels, H, W).
+            img_metas (list[dict]): Meta information of each image, e.g.,
+                image size, scaling factor, etc.
+            rescale (bool): If True, return boxes in original image space.
+                Default: False.
+            with_nms (bool): If True, do nms before return boxes.
+                Default: True.
+
+        Returns:
+            tuple[Tensor, Tensor]: First tensor bboxes with shape
+            [N, num_det, 5], 5 arrange as (x1, y1, x2, y2, score)
+            and second element is class labels of shape [N, num_det].
+        """
+        assert tl_heats[-1].shape[0] == br_heats[-1].shape[0] == len(
+            img_metas) == 1
+        result_list = []
+        for img_id in range(len(img_metas)):
+            result_list.append(
+                self._get_bboxes_single(
+                    tl_heats[-1][img_id:img_id + 1, :],
+                    br_heats[-1][img_id:img_id + 1, :],
+                    tl_offs[-1][img_id:img_id + 1, :],
+                    br_offs[-1][img_id:img_id + 1, :],
+                    img_metas[img_id],
+                    tl_emb=tl_embs[-1][img_id:img_id + 1, :],
+                    br_emb=br_embs[-1][img_id:img_id + 1, :],
+                    rescale=rescale,
+                    with_nms=with_nms))
+
+        detections, labels = result_list[0]
+        # batch_size 1 here, [1, num_det, 5], [1, num_det]
+        return detections.unsqueeze(0), labels.unsqueeze(0)
